const Clutter		= imports.gi.Clutter
const GObject		= imports.gi.GObject
const St			= imports.gi.St
const PanelMenu		= imports.ui.panelMenu
const Me			= imports.misc.extensionUtils.getCurrentExtension()
const AppManager	= Me.imports.AppManager;

var TrayIndicator = new imports.lang.Class({
	Name: 'TrayIndicator',
	Extends: PanelMenu.Button,

	_init(size) {
		this._size  = size
		this._icons = []

		this.parent(0.0, null, true);

		this._indicators = new St.BoxLayout()
		this._indicators.set_style('margin-left: 6px');
		this.add_child(this._indicators);

		this.style_class = 'nope';
	},

	get size() {
		const context = St.ThemeContext.get_for_stage(global.stage)
		return this._size * context.scale_factor
	},

	addIcon(icon) {
		this._icons.push(icon)

		const mask = St.ButtonMask.ONE | St.ButtonMask.TWO | St.ButtonMask.THREE
		const ibtn = new St.Button({ child: icon, button_mask: mask })

		ibtn.set_style('padding: 0 8px; margin: 0 2px;');

		this._indicators.add_child(ibtn)

		icon.connect('destroy', () => { ibtn.destroy() })
		ibtn.connect('button-release-event', (actor, event) => { 
			if(event) {
				switch(event.get_button()) {
					case 1: AppManager.toggleWindows(icon, event);		break;
					case 2: AppManager.killWindows(icon, event);		break;
					case 3: icon.click(event);							break;
				}
			}
		})

		icon.set_width(this.size)
		icon.set_height(this.size)
		icon.set_y_align(Clutter.ActorAlign.CENTER)
	},

	removeIcon(icon) {
		const actor = icon.get_parent() || icon
		actor.destroy()

		const index = this._icons.indexOf(icon)
		this._icons.splice(index, 1)
	}
});