const Main				= imports.ui.main
const Shell				= imports.gi.Shell
const Me				= imports.misc.extensionUtils.getCurrentExtension()
const TrayIndicator		= Me.imports.TrayIndicator
const getSettings		= Me.imports.utils.getSettings;

var TrayIconsClass = new imports.lang.Class({
	Name: 'Tray Icons: Reloaded',

	_init() {
		_settings = getSettings();

		this.tray       = new Shell.TrayManager()
		this.indicators = new TrayIndicator.TrayIndicator(_settings.get_int('icon-size'))

		this.tray.connect('tray-icon-added', this._onIconAdded.bind(this))
		this.tray.connect('tray-icon-removed', this._onIconRemoved.bind(this))

		Main.panel.addToStatusArea('TrayIconsReloaded', this.indicators, 0, _settings.get_string('tray-position'))

		this.tray.manage_screen(Main.panel)

		this._onChange();
	},

	_onIconAdded(trayManager, icon)		 {		this.indicators.addIcon(icon) 		},
	_onIconRemoved(trayManager, icon)	 {		this.indicators.removeIcon(icon)	},

	_onChange() {
		_settings.connect('changed::icon-size', () => {
			let size = _settings.get_int('icon-size');
			this.indicators._icons.forEach(icon => {
				icon.set_width(size)
				icon.set_height(size)
			});
		});

        _settings.connect('changed::tray-position', () => {
			let trayPosition = _settings.get_string('tray-position');
			Main.panel.addToStatusArea('TrayIconsReloaded' + Math.random(), this.indicators, 0, trayPosition)
		});
	},

	_destroy() {
		this.tray = null

		this.indicators.destroy()
	}
});

let TrayIcons;

class Extension {
    enable() {
        TrayIcons = new TrayIconsClass();
    }

    disable() { 
		TrayIcons._destroy();
	}
}

function init() {
    return new Extension();
}